#import <Foundation/Foundation.h>

/**
 Represents a service found on the network.
 */
@interface SDService : NSObject

/**
 Construct a new service.
 
 @param name The name of the service.
 @param hostname The hostname of the service.
 @param port The port of the service.
 @param type The type of the service.
 @param TXTRecord The TXT record of the service.
 
 @return Returns the new service.
 */
+ (SDService*)serviceWithName:(NSString*)name
                     hostname:(NSString*)hostname
                         port:(NSInteger)port
                         type:(NSString*)type
                    TXTRecord:(NSDictionary*)TXTRecord;

/**
 Initialize a new service.
 
 @param name The name of the service.
 @param hostname The hostname of the service.
 @param port The port of the service.
 @param type The type of the service.
 @param TXTRecord The TXT record of the service.
 
 @return Returns the initialized service.
 */
- (id)initWithName:(NSString*)name
          hostname:(NSString*)hostname
              port:(NSInteger)port
              type:(NSString*)type
         TXTRecord:(NSDictionary*)TXTRecord;

/**
 The name of the service.
 */
@property (strong, readonly) NSString* name;

/**
 The hostname of the service.
 */
@property (strong, readonly) NSString* hostname;

/**
 The port of the service.
 */
@property (readonly) NSInteger port;

/**
 The type of the service.
 */
@property (strong, readonly) NSString* type;

/**
 The TXT record of the service.
 */
@property (strong, readonly) NSDictionary* TXTRecord;

@end
